@@ -12,6 +12,7 @@ use crate::safeurl::{ContentType, SafeUrl, XorUrl};
 use crate::{Error, Result, Safe};
 
 use log::debug;
+use rand::Rng;
 use safe_network::types::DataAddress;
 use std::collections::BTreeSet;
 use xor_name::XorName;
@@ -19,7 +20,7 @@ use xor_name::XorName;
 pub type MultimapKey = Vec<u8>;
 pub type MultimapValue = Vec<u8>;
 pub type MultimapKeyValue = (MultimapKey, MultimapValue);
-pub type MultimapKeyValues = BTreeSet<(EntryHash, MultimapKeyValue)>;
+pub type Multimap = BTreeSet<(EntryHash, MultimapKeyValue)>;
 
 const MULTIMAP_REMOVED_MARK: &[u8] = b"";
 
@@ -37,11 +38,11 @@ impl Safe {
     }
 
     /// Return the value of a Multimap on the network corresponding to the key provided
-    pub async fn multimap_get_by_key(&self, url: &str, key: &[u8]) -> Result<MultimapKeyValues> {
+    pub async fn multimap_get_by_key(&self, url: &str, key: &[u8]) -> Result<Multimap> {
         debug!("Getting value by key from Multimap at: {}", url);
         let safeurl = self.parse_and_resolve_url(url).await?;
 
-        self.fetch_multimap_value_by_key(&safeurl, key).await
+        self.fetch_multimap_values_by_key(&safeurl, key).await
     }
 
     /// Return the value of a Multimap on the network corresponding to the hash provided
@@ -56,14 +57,15 @@ impl Safe {
         self.fetch_multimap_value_by_hash(&safeurl, hash).await
     }
 
-    // Return the value (by a provided key) of a Multimap on
-    // the network without resolving the SafeUrl
-    pub(crate) async fn fetch_multimap_value_by_key(
+    /// Fetch a multimap without resolving the URL, then filter it for all values matching a key.
+    ///
+    /// The filtered result is a Multimap itself.
+    pub(crate) async fn fetch_multimap_values_by_key(
         &self,
         safeurl: &SafeUrl,
         key: &[u8],
-    ) -> Result<MultimapKeyValues> {
-        let entries = self.fetch_multimap_values(safeurl).await?;
+    ) -> Result<Multimap> {
+        let entries = self.fetch_multimap(safeurl).await?;
         Ok(entries
             .into_iter()
             .filter(|(_, (entry_key, _))| entry_key == key)
@@ -86,7 +88,7 @@ impl Safe {
         })?;
 
         let data = serialised_entry.to_vec();
-        let safeurl = Safe::parse_url(multimap_url)?;
+        let safeurl = SafeUrl::from_url(multimap_url)?;
         let address = match safeurl.address() {
             DataAddress::Register(reg_address) => reg_address,
             other => {
@@ -98,15 +100,16 @@ impl Safe {
             }
         };
 
-        let (entry_hash, op_batch) = self
-            .client
-            .write_to_register(address, data, replace)
-            .await?;
-
-        if !self.dry_run_mode {
-            self.client.publish_register_ops(op_batch).await?;
+        if self.dry_run_mode {
+            return Ok(EntryHash(rand::thread_rng().gen::<[u8; 32]>()));
         }
 
+        let client = self.get_safe_client()?;
+
+        let (entry_hash, op_batch) = client.write_to_register(address, data, replace).await?;
+
+        client.publish_register_ops(op_batch).await?;
+
         Ok(entry_hash)
     }
 
@@ -120,7 +123,7 @@ impl Safe {
         to_remove: BTreeSet<EntryHash>,
     ) -> Result<EntryHash> {
         debug!("Removing from Multimap at {}: {:?}", url, to_remove);
-        let safeurl = Safe::parse_url(url)?;
+        let safeurl = SafeUrl::from_url(url)?;
         let address = match safeurl.address() {
             DataAddress::Register(reg_address) => reg_address,
             other => {
@@ -131,14 +134,18 @@ impl Safe {
                 )))
             }
         };
-        let (entry_hash, op_batch) = self
-            .client
+
+        if self.dry_run_mode {
+            return Ok(EntryHash(rand::thread_rng().gen::<[u8; 32]>()));
+        }
+
+        let client = self.get_safe_client()?;
+
+        let (entry_hash, op_batch) = client
             .write_to_register(address, MULTIMAP_REMOVED_MARK.to_vec(), to_remove)
             .await?;
 
-        if !self.dry_run_mode {
-            self.client.publish_register_ops(op_batch).await?;
-        }
+        client.publish_register_ops(op_batch).await?;
 
         Ok(entry_hash)
     }
@@ -146,10 +153,7 @@ impl Safe {
     // Crate's helper to return the value of a Multimap on
     // the network without resolving the SafeUrl,
     // filtering by hash if a version is provided
-    pub(crate) async fn fetch_multimap_values(
-        &self,
-        safeurl: &SafeUrl,
-    ) -> Result<MultimapKeyValues> {
+    pub(crate) async fn fetch_multimap(&self, safeurl: &SafeUrl) -> Result<Multimap> {
         let entries = match self.register_fetch_entries(safeurl).await {
             Ok(data) => {
                 debug!("Multimap retrieved...");
@@ -167,16 +171,16 @@ impl Safe {
         }?;
 
         // We parse each entry in the Register as a 'MultimapKeyValue'
-        let mut multimap_key_vals = MultimapKeyValues::new();
+        let mut multimap = Multimap::new();
         for (hash, entry) in entries.iter() {
             if entry == MULTIMAP_REMOVED_MARK {
                 // this is a tombstone entry created to delete some old entries
                 continue;
             }
             let key_val = Self::decode_multimap_entry(entry)?;
-            multimap_key_vals.insert((*hash, key_val));
+            multimap.insert((*hash, key_val));
         }
-        Ok(multimap_key_vals)
+        Ok(multimap)
     }
 
     // Crate's helper to return the value of a Multimap on
