@@ -24,7 +24,7 @@ impl Safe {
     /// Parses a string URL "safe://url" and returns a safe URL
     /// Resolves until it reaches the final URL
     pub async fn parse_and_resolve_url(&self, url: &str) -> Result<SafeUrl> {
-        let safe_url = Safe::parse_url(url)?;
+        let safe_url = SafeUrl::from_url(url)?;
         let orig_path = safe_url.path_decoded()?;
 
         // Obtain the resolution chain without resolving the URL's path
@@ -78,7 +78,7 @@ impl Safe {
     /// # });
     /// ```
     pub async fn fetch(&self, url: &str, range: Range) -> Result<SafeData> {
-        let safe_url = Safe::parse_url(url)?;
+        let safe_url = SafeUrl::from_url(url)?;
         info!("URL parsed successfully, fetching: {}", url);
 
         let mut resolution_chain = self
@@ -132,8 +132,8 @@ impl Safe {
     ///
     /// # });
     /// ```
-    pub async fn inspect(&mut self, url: &str) -> Result<Vec<SafeData>> {
-        let safe_url = Safe::parse_url(url)?;
+    pub async fn inspect(&self, url: &str) -> Result<Vec<SafeData>> {
+        let safe_url = SafeUrl::from_url(url)?;
         info!("URL parsed successfully, inspecting: {}", url);
         self.fully_resolve_url(safe_url, None, false, None, true)
             .await
@@ -251,7 +251,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_fetch_files_container() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
+        let safe = new_safe_instance().await?;
         let (fc_xorurl, _, original_files_map) = safe
             .files_container_create_from("./testdata/", None, true, false)
             .await?;
@@ -302,7 +302,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_fetch_resolvable_container() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
+        let safe = new_safe_instance().await?;
 
         // create file container
         let (xorurl, _, the_files_map) = safe
@@ -362,7 +362,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_fetch_resolvable_map_data() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
+        let safe = new_safe_instance().await?;
 
         // create file container
         let (xorurl, _, _the_files_map) = safe
@@ -429,7 +429,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_fetch_public_file() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
+        let safe = new_safe_instance().await?;
         let data = Bytes::from("Something super immutable");
         let xorurl = safe
             .store_public_bytes(data.clone(), Some("text/plain"))
@@ -449,6 +449,47 @@ mod tests {
                 }
         );
 
+        let inspected_content = safe.inspect(&xorurl).await?;
+        assert!(
+            inspected_content[0]
+                == SafeData::PublicFile {
+                    xorurl: xorurl.clone(),
+                    xorname: safe_url.xorname(),
+                    data: Bytes::new(),
+                    resolved_from: xorurl,
+                    media_type: Some("text/plain".to_string()),
+                    metadata: None,
+                }
+        );
+        Ok(())
+    }
+
+    #[tokio::test]
+    async fn test_fetch_public_file_from_nrs_url() -> Result<()> {
+        let safe = new_safe_instance().await?;
+        let data = Bytes::from("Something super immutable");
+        let xorurl = safe
+            .store_public_bytes(data.clone(), Some("text/plain"))
+            .await?;
+
+        let safe_url = SafeUrl::from_url(&xorurl)?;
+        let site_name: String = thread_rng().sample_iter(&Alphanumeric).take(15).collect();
+        let public_name = format!("file.{site_name}");
+        safe.nrs_add(&public_name, &safe_url).await?;
+
+        let content = retry_loop!(safe.fetch(&format!("safe://{public_name}"), None));
+        assert!(
+            content
+                == SafeData::PublicFile {
+                    xorurl: xorurl.clone(),
+                    xorname: safe_url.xorname(),
+                    data: data.clone(),
+                    resolved_from: xorurl.clone(),
+                    media_type: Some("text/plain".to_string()),
+                    metadata: None,
+                }
+        );
+
         // let's also compare it with the result from inspecting the URL
         let inspected_content = safe.inspect(&xorurl).await?;
         assert!(
@@ -502,7 +543,7 @@ mod tests {
     #[tokio::test]
     async fn test_fetch_range_from_files_container() -> Result<()> {
         use std::fs::File;
-        let mut safe = new_safe_instance().await?;
+        let safe = new_safe_instance().await?;
 
         // create file container
         let (xorurl, _, _files_map) = safe
@@ -558,7 +599,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_fetch_unsupported_with_media_type() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
+        let safe = new_safe_instance().await?;
         let xorname = rand::random();
         let type_tag = 575_756_443;
         let xorurl = SafeUrl::encode(
